@@ -29,12 +29,30 @@
 #include "mainwindow.h"
 #include "bovo_version.h"
 
+#define HAVE_KICONTHEME __has_include(<KIconTheme>)
+#if HAVE_KICONTHEME
+#include <KIconTheme>
+#endif
+
+#define HAVE_STYLE_MANAGER __has_include(<KStyleManager>)
+#if HAVE_STYLE_MANAGER
+#include <KStyleManager>
+#endif
 using namespace gui;
 
 int main(int argc, char **argv) {
+#if HAVE_KICONTHEME
+    KIconTheme::initTheme();
+#endif
 
     QApplication app(argc, argv);
-
+#if HAVE_STYLE_MANAGER
+    KStyleManager::initStyle();
+#else // !HAVE_STYLE_MANAGER
+#if defined(Q_OS_MACOS) || defined(Q_OS_WIN)
+    QApplication::setStyle(QStringLiteral("breeze"));
+#endif // defined(Q_OS_MACOS) || defined(Q_OS_WIN)
+#endif // HAVE_STYLE_MANAGER
     KLocalizedString::setApplicationDomain(QByteArrayLiteral("bovo"));
 
     KAboutData aboutData(QStringLiteral("bovo"), i18n("Bovo"),
